pub struct Template(/* private fields */);Expand description
Template holds the prepared result of parsing a template. Because the template does not need to be reparsed, subsequent executions come at a low cost.
Implementations
Sourceimpl Template
impl Template
Sourcepub fn render(&self, ctx: &impl Context) -> Result<String>
pub fn render(&self, ctx: &impl Context) -> Result<String>
Render a template as a string.
Usage
let t = Templar::global().parse_expression("5 + 5")?;
assert_eq!(t.render(&context)?, "10");Sourcepub fn exec(&self, ctx: &impl Context) -> Data
pub fn exec(&self, ctx: &impl Context) -> Data
Execute a template, getting a InnerData from the unstructured crate as a result.
many of the native rust types implement into() on InnerData making direct comparisons
easy.
Usage
let t = Templar::global().parse_expression("5 + 5")?;
assert_eq!(*t.exec(&context), 10i64);Trait Implementations
Sourceimpl From<Template> for TemplateTree
impl From<Template> for TemplateTree
Sourcefn from(t: Template) -> TemplateTree
fn from(t: Template) -> TemplateTree
Converts to this type from the input type.
Sourceimpl TryFrom<Option<TemplateTree>> for Template
impl TryFrom<Option<TemplateTree>> for Template
Sourcetype Error = TemplarError
type Error = TemplarError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<TemplateTree> for Template
impl TryFrom<TemplateTree> for Template
Sourcetype Error = TemplarError
type Error = TemplarError
The type returned in the event of a conversion error.
Sourcefn try_from(value: TemplateTree) -> Result<Self>
fn try_from(value: TemplateTree) -> Result<Self>
Performs the conversion.